## **Journal of Sports Sciences**

**[ISSN: 0264-0414 (Print) 1466-447X (Online) Journal homepage: http://www.tandfonline.com/loi/rjsp20](http://www.tandfonline.com/loi/rjsp20)**

# **The validity and reliability of an iPhone app for** **measuring vertical jump performance**

**Carlos Balsalobre-Fernández, Mark Glaister & Richard Anthony Lockey**

**To cite this article:** Carlos Balsalobre-Fernández, Mark Glaister & Richard Anthony Lockey
(2015) The validity and reliability of an iPhone app for measuring vertical jump performance,
[Journal of Sports Sciences, 33:15, 1574-1579, DOI: 10.1080/02640414.2014.996184](http://www.tandfonline.com/action/showCitFormats?doi=10.1080/02640414.2014.996184)

**To link to this article:** [http://dx.doi.org/10.1080/02640414.2014.996184](http://dx.doi.org/10.1080/02640414.2014.996184)

Published online: 02 Jan 2015.

[Submit your article to this journal](http://www.tandfonline.com/action/authorSubmission?journalCode=rjsp20&show=instructions)

Article views: 2668

[View related articles](http://www.tandfonline.com/doi/mlt/10.1080/02640414.2014.996184)

[View Crossmark data](http://crossmark.crossref.org/dialog/?doi=10.1080/02640414.2014.996184&domain=pdf&date_stamp=2015-01-02)

[Citing articles: 7 View citing articles](http://www.tandfonline.com/doi/citedby/10.1080/02640414.2014.996184#tabModule)

Full Terms & Conditions of access and use can be found at
[http://www.tandfonline.com/action/journalInformation?journalCode=rjsp20](http://www.tandfonline.com/action/journalInformation?journalCode=rjsp20)

**Download by:** \[80.82.78.170\] **Date:** 14 December 2016, At: 05:22

Journal of Sports Sciences, 2015

–
Vol. 33, No. 15, 1574 1579, <http://dx.doi.org/10.1080/02640414.2014.996184>

### The validity and reliability of an iPhone app for measuring vertical jump performance

CARLOS BALSALOBRE-FERNÁNDEZ \[1\], MARK GLAISTER \[2\] &
RICHARD ANTHONY LOCKEY \[2\]

1Department of Physical Education, Sport and Human Movement, Autonomous University of Madrid, Madrid, Spain and
2School of Sport, Health and Applied Science, St Mary’s University, Twickehnham, United Kingdom

(Accepted 4 December 2014)

Abstract
The purpose of this investigation was to analyse the concurrent validity and reliability of an iPhone app (called: My Jump)
for measuring vertical jump performance. Twenty recreationally active healthy men (age: 22.1 ± 3.6 years) completed five
maximal countermovement jumps, which were evaluated using a force platform (time in the air method) and a specially
designed iPhone app. My jump was developed to calculate the jump height from flight time using the high-speed video
recording facility on the iPhone 5 s. Jump heights of the 100 jumps measured, for both devices, were compared using the
intraclass correlation coefficient, Pearson product moment correlation coefficient (r), Cronbach’s alpha (α), coefficient of
variation and Bland–Altman plots. There was almost perfect agreement between the force platform and My Jump for the
countermovement jump height (intraclass correlation coefficient = 0.997, P \< 0.001; Bland–Altman bias = 1.1 ± 0.5 cm,
P \< 0.001). In comparison with the force platform, My Jump showed good validity for the CMJ height (r = 0.995,
P \< 0.001). The results of the present study showed that CMJ height can be easily, accurately and reliably evaluated
using a specially developed iPhone 5 s app.

Keywords: biomechanics, fitness, physical performance, strength

Introduction

Vertical jump tests are among the most common
means of evaluating physical fitness in various populations (Buchheit, Spencer, & Ahmaidi, 2010; De
Villarreal, Izquierdo, & Gonzalez-Badillo, 2011;
Rodacki, Fowler, & Bennett, 2002; Taipale,
Mikkola, Vesterinen, Nummela, & Häkkinen, 2013).
Though principally used to evaluate leg power in
sports, such as basketball and football (Argus, Gill,
Keogh, Hopkins, & Beaven, 2009; Duncan, Lyons, &
Nevill, 2008; Hartman, Clark, Bemben, Kilgore, &
Bemben, 2007), vertical jump tests have also been
used to evaluate non-athletic populations (including
children (Acero et al., 2011) and elderly people
(Pereira et al., 2012)), particularly because vertical
jump training has been reported to improve bone
mineral density (Allison, Folland, Rennie, Summers,
& Brooke-Wavell, 2013). Vertical jump tests have
been proposed as important for talent identification
purposes, with young elite athletes displaying higher
values than their non-elite counterparts (Fry et al.,
2006; Gabbett, Georgieff, & Domrow, 2007).

Moreover, the height jumped, in addition to providing an indication of lower limb muscular power
(Markovic, Dizdar, Jukic, & Cardinale, 2004) and
neuromuscular fatigue (Buchheit et al., 2010;
Sánchez-Medina & González-Badillo, 2011), has
shown strong negative correlations (r > −0.90) with
indices of exercise exhaustion and stress such as

blood lactate (Sánchez-Medina & González-Badillo,
2011), ammonia (Sánchez-Medina & GonzálezBadillo, 2011) and salivary-free cortisol concentrations (Balsalobre-Fernández, Tejero-González, &
Del Campo-Vecino, 2014).

Several different approaches exist for measuring vertical jump height, with force platforms being considered the gold standard (Glatthorn et al., 2011;
Requena, Requena, García, De Villarreal, & Pääsuke,
2012; Sayers, Harackiewicz, Harman, Frykman, &
Rosenstein, 1999). Force platforms can measure vertical jump height using both time in the air and take-off
velocity methods (Kibele, 1998; Moir, 2008). While
take-off velocity is considered the most accurate
method for measuring vertical jump height, time in

Correspondence: Carlos Balsalobre-Fernández, Department of Physical Education, Sport and Human Movement, Autonomous University of Madrid, Madrid,
Spain. E-mail: <carlos.balsalobre@icloud.com>

© 2014 Taylor & Francis

the air method has been proved to be highly valid and
reliable too, and most instrumental nowadays calculate
jump height by measuring the flight time of the jump
(Glatthorn et al., 2011; Moir, 2008; Requena et al.,
2012). Although force platforms, accelerometers, contact platforms, infrared platforms and high-speed cameras (Casartelli, Müller, & Maffiuletti, 2010; Glatthorn
et al., 2011; Requena et al., 2012) have been validated
for measuring the flight time of vertical jumps, all of
them have potential drawbacks. First, most of these
devices are expensive for coaches and personal trainers
and, as such, their use is largely confined to University
laboratories and/or elite sports clubs. Second, these
instruments can be bulky and often need specific computer software to analyse the data. Although the portability of this type of equipment has improved in recent
years, it still provides a restriction which could affect its
usability in field situations.

An inexpensive, portable approach for measuring vertical jump performance was validated
recently (Balsalobre-Fernández, Tejero-González,
Del Campo-Vecino, & Bavaresco, 2014), which
combines the use of a low cost high-speed camera
and license-free computer software to evaluate vertical jump height. However, the approach still
requires the transfer of video footage from the camera to the software to calculate the vertical jump
height, thereby slowing the evaluation process.
This process usually takes 5 min of video transferring plus 30 s for each jump height calculation
according to the authors.

Recently, Apple Inc. (USA) released the iPhone
5 s, an update of its smartphone, and one of its new
features is a high-speed camera capable of recording
120 Hz. As such, with the development of an appropriate application (app), the phone has the potential
to record high-speed videos and subsequently calculate jump height directly. However, there are no previous studies validating an iPhone app for measuring
vertical jump height. The aim of the present study,
therefore, was to analyse the validity and reliability of
a specifically designed iPhone app (named: My Jump)
for measuring vertical jump height.

Methods

Participants

Twenty recreationally active, healthy, sport sciences
male students (N = 20, age = 22.1 ± 3.6 years,
height = 1.81 ± 0.08 m, body mass = 74.0 ± 10.4 kg,

– –
countermovementjump CMJ height=35.2±5.4cm)
were recruited for this study. The study protocol complied with the Declaration of Helsinki for Human
Experimentation and was approved by St Mary’s
University Ethics Committee. Written informed

iPhone app for measuring vertical jumps 1575

consent was obtained from each participant before
participation.

Study design

The participants completed a standard 10-min
warm-up composed of jogging, lower body dynamic
stretches and vertical jumps. Then, each participant
performed five CMJs on a force platform (Kistler
9287 BA, Kistler Instruments Ltd., Hook, UK)
while being recorded with an iPhone 5 s (Apple
Inc., USA) high-speed camera. All participants had
experience on CMJ testing. Each jump was separated by a 2 min passive rest period. The app
(named: My Jump), which was developed ad hoc for
this study, calculated the flight time of the CMJ by
identifying the take-off and the landing frames of the
video, and then transforming it into a jump height
using the equation described in the literature (Bosco,
Luhtanen, & Komi, 1983): h ¼ t \[2\] � 1:22625, with h
being the jump height in metres and t being the flight
time of the jump in seconds. The same equation was
also used to calculate jump heights from the force
platform data.

Countermovement jump performance

Participants performed each CMJ with hands on
their hips, starting from a static standing position
and with their legs straight during the flight phase
of the jump (Haekkinen & Komi, 1985). The landing was performed simultaneously with either feet
keeping ankle dorsiflexion. Participants were
instructed to jump as high as possible.

Equipment

App for the iPhone 5s. The app to calculate CMJ
height was developed using the software (XCode
5.0.5 for Mac OSX 10.9.2; Apple Inc., USA) specifically designed to provide the necessary tools to
write apps for the iPhone 5 s using Objective-C
language. When finished, the app (named: My
Jump) was installed on an iPhone 5 s, which includes
a 120 Hz high-speed camera, at a quality of 720 p.
My Jump was designed for analysing vertical jumps
to allow the calculation of the time (in ms) between
two frames selected by the user and subsequently to
calculate the height of the CMJ using the equation
described above.

To record the CMJ with My Jump, a researcher lay
prone on the ground with the iPhone 5 s facing the
participant (in the frontal plane), at ~1.5 m from the
force platform, and zooming in on the feet of the
participant. Two independent observers, with no
prior experience on video analysis, were asked to
select, with My Jump, the first frame in which both

1576 C. Balsalobre-Fernández et al.

Figure 1. User interface of the app designed for this study.

feet were off the ground (take-off phase) and subsequently, the first frame in which at least one foot was
touching the ground (landing phase). See Figure 1.

My Jump is available on the Appstore (Apple
Inc., USA).

Force platform. The force platform (600 × 900 mm)
recorded data at a sampling frequency of 1000 Hz
and was used to measure the flight times of the
CMJ at the same time as they were being recorded
on the iPhone 5 s. The force platform was connected to a PC equipped with the software to
analyse the force data (BioWare V5.2.2.4, Kistler
Holding AG, Switzerland). Flight times from the
analysis of the force platform data were used to
calculate jump height using the same equation
described earlier.

Statistical analyses

Several analyses were conducted to determine the
reliability and validity of CMJ height using the app.
First, to analyse the reliability of the app for measuring the CMJ height in comparison with the force
platform data, the intraclass correlation coefficient
(ICC) (2,1) was used. Second, to analyse the stability of the app when measuring the five CMJ of each
participant, Cronbach’s α and the coefficient of
variation (CV) were used. Third, to complement

–
the ICC analyses, Bland Altman plots were created, which are known to give a good representation
of the agreement between the two instruments
(Bland & Altman, 1986). Fourth, to calculate the
concurrent validity, the bivariate Pearson product
moment correlation coefficient (r) was used.
Finally, to analyse the reliability of the app between
observers, an ICC was used. The level of statistical
significance was set at P \< 0.05. All calculations
were performed using IBM SPSS Statistics 22 for
Mac (IBM Co., USA).

Results

There was almost perfect agreement between the My
Jump and the force platform CMJ jump heights
(ICC = 0.997, 95% CI: 0.996–0.998, P \< 0.001)
for both observers, with a mean difference of
1.1 ± 0.5 cm (observer 1) and 1.3 ± 0.5 cm (observer 2) between instruments. My Jump values were
significantly lower than those obtained with the force
platform (P \< 0.05). See Figure 2.

The app showed very good reliability for the five
CMJ of each participant for jump height (observer 1:
α = 0.997, CV = 3.4%; observer 2: α = 0.988,
CV = 3.6%). Also, the Pearson product moment
correlation coefficient showed almost perfect correlation between the app and the force platform measurements for jump height (r = 0.995, P \< 0.001).
See Figure 3.

Finally, when analysing the reliability of the app,
almost perfect agreement between observer calculations was found for jump height (ICC = 0.999, 95%
CL = 0.998–0.999, P \< 0.001). The mean difference
between observers was 0.1 ± 0.4 cm. See Figure 4.

Discussion

The purpose of this study was to analyse the concurrent validity and reliability of an iPhone app for
measuring CMJ performance. My Jump was found
to be highly valid and reliable in measuring the
jump height of a CMJ in comparison with a force

–
platform. Moreover, the data presented in Bland
Altman plots (Figures 2 and 4) showed that most of
the CMJ values are close to the mean of the

–
Figure 2. Bland Altman plots for the force platform and My Jump
app jump height data. The central line represents the absolute
average difference between instruments, while the upper and the
lower lines represent ±1.96 s.

Figure 3. Concurrent validity between the force platform and My
Jump app.

–
Figure 4. Bland Altman plots between observers for jump height.
The central line represents the absolute average difference
between observers, while the upper and the lower lines represent

±1.96 s.

differences between instruments (1.1 ± 0.5 cm) or
observers (0.1 ± 0.4 cm), thereby representing a
high level of agreement (Bland & Altman, 1986).
Specifically, the differences between observers on
the measurements of the jump height were very
small (about 1 mm), despite the fact that the takeoff and landing frame selection had to be performed
manually, which could increase the measurement
error. Moreover, it is worth mentioning that the
observers had no previous experience on video analysis, which highlights the usability of My Jump.
Also, when analysing the reliability of My Jump for
measuring the five CMJ for each participant, the
results showed values that were very close to the

iPhone app for measuring vertical jumps 1577

ones obtained with the force platform (considered
the gold standard for vertical jumps measurements
(Duncan et al., 2008)), despite differences between
devices in sampling frequency.

Previous studies have compared different technologies for measuring vertical jumps with force platform data. It has been demonstrated that an infrared

platform has a difference of about 1.0 cm in comparison with a force platform at 1000 Hz (Glatthorn
et al., 2011). Also, it was shown that an accelerometric system (Myotest SA, Switerzland) has a mean
difference of 3.6 cm in comparison with a force platform at 1000 Hz (Choukou, Laffaye, & Taiar, 2014),
higher than the app analysed in this study. Probably,
the most accurate systems for measuring vertical
jump height (besides force platforms) are professional high-speed cameras (Balsalobre-Fernández
et al., 2014; García-López et al., 2005; Requena
et al., 2012). For example, a professional highspeed camera recording at 1000 Hz has a difference
of just 1.3 ms of flight time in comparison with a
1000 Hz force platform (Requena et al., 2012).
Taking into account that information, the accuracy
of My Jump (about 8.9 ms of flight time or 1.2 cm of
jump height) compares well with much more expensive and less portable devices. Moreover, the rapid
advancement of new technologies suggests that, in
the near future, smartphones will include cameras
with higher recording frequencies that will reduce
the measurement error of the My Jump. In fact,
after we submitted the first version of this manuscript, Apple announced the new iPhone 6 featuring
a 240 Hz high-speed camera. Indeed, it has been
suggested that smartphones apps, because of their
popularity, affordability, portability and advanced
technology, will soon be a commonplace for measuring variables (such as CMJ height) associated with
physical performance and health with great accuracy
(Bort-Roig, Gilson, Puig-Ribera, Contreras, &
Trost, 2014).

The major drawback of My Jump is that, since it
records videos at 120 Hz, there is a chance that the
take-off and/or the landing frame will not be
recorded. The equation for the calculation of the
jump height uses the flight time squared, which
means that the measurement error increases with
longer flight times (Balsalobre-Fernández et al.,
2014). However, the highest CMJ measured on this
study, which was higher than an average professional
basketball player (Alemdaroğlu, 2012) (51.5 cm),
had a difference of only 1.6 cm with respect to the
force platform. As such, My Jump is able to measure
jump heights accurately for most populations,
including trained athletes, and requires no prior
video analysis experience. This is the first study
that validates a commercial iPhone app for measuring vertical jump height.

1578 C. Balsalobre-Fernández et al.

Conclusions

The ability to evaluate and monitor CMJ ability is
important in areas of health, talent identification and
sporting performance. The results of the present
study showed that CMJ height can be easily, accurately and reliably evaluated using a specially developed iPhone 5 s app (named: My Jump) which is
available on the Appstore (Apple Inc., USA). These
findings could help coaches and trainers who wish to
monitor the vertical jump ability of their athletes or
clients in a valid and economic way.

Conflicts of interest

The first author of the article is the co-designer of
the app mentioned. The data from the app were
obtained from two independent observers not
related to the app development.

References

Acero, R. M., Fernández-del Olmo, M., Sánchez, J. A., Otero, X.
L., Aguado, X., & Rodríguez, F. A. (2011). Reliability of squat
and countermovement jump tests in children 6 to 8 years of
age. Pediatric Exercise Science, 23(1), 151–160.
Alemdaroğlu, U. (2012). The relationship between muscle
strength, anaerobic performance, agility, sprint ability and vertical jump performance in professional basketball players.
Journal of Human Kinetics, 31, 149–158.
Allison, S. J., Folland, J. P., Rennie, W. J., Summers, G. D., &
Brooke-Wavell, K. (2013). High impact exercise increased
femoral neck bone mineral density in older men: A randomised
unilateral intervention. Bone, 53(2), 321–328.
Argus, C. K., Gill, N. D., Keogh, J. W. L., Hopkins, W. G., &
Beaven, C. M. (2009). Changes in strength, power, and
steroid hormones during a professional rugby union competition. Journal of Strength & Conditioning Research, 23(5),

1583–1592.

Balsalobre-Fernández, C., Tejero-González, C. M., & Del
Campo-Vecino, J. (2014). Hormonal and neuromuscular
responses to high level middle and long-distance competition.
International Journal of Sports Physiology and Performance, 9,

839–844.

Balsalobre-Fernández, C., Tejero-González, C. M., Del
Campo-Vecino, J., & Bavaresco, N. (2014). The concurrent
validity and reliability of a low-cost, high-speed camerabased method for measuring the flight time of vertical
jumps. Journal of Strength & Conditioning Research, 28(2),

528–533.

Bland, J. M., & Altman, D. G. (1986). Statistical methods for
assessing agreement between two methods of clinical measurement. The Lancet, 327(8476), 307–310.
Bort-Roig, J., Gilson, N. D., Puig-Ribera, A., Contreras, R. S., &
Trost, S. G. (2014). Measuring and influencing physical activity with smartphone technology: A systematic review. Sports
Medicine (Auckland, N.Z.), 44, 671–686.
Bosco, C., Luhtanen, P., & Komi, P. V. (1983). A simple method
for measurement of mechanical power in jumping. European
Journal of Applied Physiology and Occupational Physiology, 50(2),

273–282.

Buchheit, M., Spencer, M., & Ahmaidi, S. (2010). Reliability,
usefulness, and validity of a repeated sprint and jump ability
test. International Journal of Sports Physiology & Performance,
5(1), 3–17.

Casartelli, N., Müller, R., & Maffiuletti, N. A. (2010). Validity
and reliability of the myotest accelerometric system for the
assessment of vertical jump height. Journal of Strength &
Conditioning Research, 24(11), 3186–3193.
Choukou, M. A., Laffaye, G., & Taiar, R. (2014). Reliability and
validity of an accelerometric system for assessing vertical jumping performance. Biology of Sport, 31(1), 55–62.
De Villarreal, E. S. S., Izquierdo, M., & Gonzalez-Badillo, J.
(2011). Enhancing jump performance after combined vs.
maximal power, heavy-resistance, and plyometric training
alone. Journal of Strength & Conditioning Research, 25(12),

3274–3281.

Duncan, M. J., Lyons, M., & Nevill, A. M. (2008). Evaluation
of peak power prediction equations in male basketball
players. Journal of Strength & Conditioning Research, 22(4),

1379–1381.

Fry, A. C., Ciroslan, D., Fry, M. D., LeRoux, C. D., Schilling, B.
K., & Chiu, L. Z. F. (2006). Anthropometric and performance
variables discriminating elite American junior men weightlifters.
Journal of Strength & Conditioning Research, 20(4), 861–866.
Gabbett, T., Georgieff, B., & Domrow, N. (2007). The use of
physiological, anthropometric, and skill data to predict selection in a talent-identified junior volleyball squad. Journal of
Sports Sciences, 25(12), 1337–1344.
García-López, J., Peleteiro, J., Rodgríguez-Marroyo, J. A.,
Morante, J. C., Herrero, J. A., & Villa, J. G. (2005). The
validation of a new method that measures contact and flight
times during vertical jump. International Journal of Sports
Medicine, 26(4), 294–302.
Glatthorn, J. F., Gouge, S., Nussbaumer, S., Stauffacher, S.,
Impellizzeri, F. M., & Maffiuletti, N. A. (2011). Validity and
reliability of optojump photoelectric cells for estimating vertical
jump height. Journal of Strength & Conditioning Research, 25(2),

556–560.

Haekkinen, K., & Komi, P. V. (1985). Effect of explosive type
strength training on electromyographic and force production
characteristics of leg extensor muscles during concentric and
various stretch-shortening cycle exercises. Scandinavian Journal
of Sports Sciences, 7(2), 65–76.
Hartman, M. J., Clark, B., Bemben, D. A., Kilgore, J. L., &
Bemben, M. G. (2007). Comparisons between twice-daily
and once-daily training sessions in male weight lifters.
International Journal of Sports Physiology & Performance, 2(2),

159–169.

Kibele, A. (1998). Possibilities and limitations in the biomechanical analysis of countermovement jumps. Journal of Applied
Biomechanics, 14(1), 105.
Markovic, G., Dizdar, D., Jukic, I., & Cardinale, M. (2004).
Reliability and factorial validity of squat and countermovement
jump tests. Journal of Strength & Conditioning Research, 18(3),

551–555.

Moir, G. L. (2008). Three different methods of calculating vertical jump height from force platform data in men and women.
Measurement in Physical Education & Exercise Science, 12(4),

207–218.

Pereira, A., Izquierdo, M., Silva, A. J., Costa, A. M., Bastos, E.,
González-Badillo, J. J., & Marques, M. C. (2012). Effects of
high-speed power training on functional capacity and muscle
performance in older women. Experimental Gerontology, 47(3),

250–255.

Requena, B., Requena, F., García, I., De Villarreal, E.-S.-S., &
Pääsuke, M. (2012). Reliability and validity of a wireless
microelectromechanicals based system (Keimove™) for measuring vertical jumping performance. Journal of Sports Science
& Medicine, 11(1), 115–122.
Rodacki, A. L. F., Fowler, N. E., & Bennett, S. J. (2002).
Vertical jump coordination: Fatigue effects. Medicine &
Science in Sports & Exercise, 34(1), 105–116.

Sánchez-Medina, L., & González-Badillo, J. J. (2011). Velocity loss
as an indicator of neuromuscular fatigue during resistance training. Medicine & Science in Sports & Exercise, 43(9), 1725–1734.
Sayers, S. P., Harackiewicz, D. V., Harman, E. A., Frykman, P.
N., & Rosenstein, M. T. (1999). Cross-validation of three
jump power equations. Medicine & Science in Sports &
Exercise, 31(4), 572–577.

iPhone app for measuring vertical jumps 1579

Taipale, R., Mikkola, J., Vesterinen, V., Nummela, A., &
Häkkinen, K. (2013). Neuromuscular adaptations during
combined strength and endurance training in endurance
runners: Maximal versus explosive strength training or a
mix of both. European Journal Of Applied Physiology, 113(2),

325–335.
